pub fn peer_reset_code(error: &StreamError) -> Option<u64>Expand description
The reset code the peer used, if this error is a peer-initiated reset.
pub fn peer_reset_code(error: &StreamError) -> Option<u64>The reset code the peer used, if this error is a peer-initiated reset.